/// <reference types="node" />
/// <reference types="pdfkit" />
import { Language } from '../LegalAnalyticsClient/websocket/Language';
import { AnalysisResultGroup } from '../models/AnalysisResultGroup';
import { ApiResponse } from '../models/ApiResponse';
/**
 * Allows to create PDF files ("result pdf") from analysis results.
 * @export
 * @class PdfGenerator
 */
export declare class PdfGenerator {
    /**
     * Creates a TCreatedPdf object with analysis results from an API response
     * for the use with pdfMake.
     * @private
     * @static
     * @param {ApiResponse} apiResponse The API response that contains the analysis results.
     * @param {string} [originalFilename] An optional parameter if the name of the analysed file should appear in the result pdf.
     * @param {string} [pdfTitle] An optional parameter that allows to adapt the title of the result pdf.
     * @return {TCreatedPdf} The TCreatedPdf object that can be used by pdfMake to perform further actions.
     * @memberof PdfGenerator
     */
    private static getPdfFromApiResponse;
    /**
     * Creates a TCreatePdf object with analysis results from an array of AnalysisResultGroup objects for the use with pdfMake.
     * @private
     * @static
     * @param {AnalysisResultGroup[]} analysisResultGroups The array of AnalysisResultGroup objects that contain the analysis results.
     * @param {string} [originalFilename] An optional parameter if the name of the analysed file should appear in the result pdf.
     * @param {string} [pdfTitle] An optional parameter that allows to adapt the title of the result pdf.
     * @return {TCreatedPdf}  The TCreatedPdf object that can be used by pdfMake to perform further actions.
     * @memberof PdfGenerator
     */
    private static getPdfFromAnalysisResultGroups;
    /**
     * Creates a TDocumentDefinitions object for analysis results from an ApiResponse.
     * @private
     * @static
     * @param {ApiResponse} apiResponse The API response that contains the analysis results.
     * @param {string} [originalFilename] An optional parameter if the name of the analysed file should appear in the result pdf.
     * @param {string} [pdfTitle] An optional parameter that allows to adapt the title of the result pdf.
     * @return {TDocumentDefinitions} The TDocumentDefinitions object that can be used with pdfMake to create a TCreatedPdf.
     * @memberof PdfGenerator
     */
    private static createDocumentDefinitionFromApiResponse;
    /**
     * Creates a TDocumentDefinitions object for analysis results from an array of AnalysisResultGroup objects.
     * @private
     * @static
     * @param {AnalysisResultGroup[]} analysisResultGroups The array of AnalysisResultGroup objects that contain the analysis results.
     * @param {string} [originalFilename] An optional parameter if the name of the analysed file should appear in the result pdf.
     * @param {string} [pdfTitle] An optional parameter that allows to adapt the title of the result pdf.
     * @return {TDocumentDefinitions} The TDocumentDefinitions object that can be used with pdfMake to create a TCreatedPdf.
     * @memberof PdfGenerator
     */
    private static createDocumentDefinitionFromAnalysisResultGroups;
    /**
     * Creates an object that stores arguments that are used during the creation of the result pdf.
     * Either the ApiResponse or the array of AnalysisResultGroups must be not null.
     * @private
     * @static
     * @param {ApiResponse} [apiResponse] An optional parameter for the ApiResponse. Can be null if an array AnalysisResultsGroup
     * @param {string} [originalFilename] An optional parameter if the name of the analysed file should appear in the result pdf.
     * @param {string} [pdfTitle] An optional parameter that allows to adapt the title of the result pdf.
     * @param {AnalysisResultGroup[]} [analysisResultGroups]
     * @return {*}  {PdfGeneratorArgs}
     * @memberof PdfGenerator
     * @throws If the ApiResponse object and the AnalysisResultGroups array are null at the same time. Exactly one of both must be not null.
     */
    private static createPdfGeneratorArgs;
    /**
     * Creates a document definition that can be used to create a new pdf file. The PdfGeneratorArgs determine, how the content of the result pdf is built.
     * @param {PdfGeneratorOptions} args The parameters that are used to build the contents of the pdf file.
     * @return {TDocumentDefinitions} The TDocumentDefinitions object that was built using the the supplied PdfGeneratorArgs.
     */
    private static getDocumentDefinition;
    /**
     * Builds the header section of the pdf document with the bold, centered title, the name of the analysed file (if supplied) and a header.
     * The header is appended to the supplied content array.
     * @param args A PdfGeneratorArgs object containing parameters for the creation of the pdf.
     * @param content The content array that is extended.
     */
    private static buildHeading;
    /**
     * Builds the content of the pdf file. Depending on if the PdfGeneratorArgs contain an ApiResponse or an array of AnalysisResultGroups, a different function is called to build the content of the result pdf.
     * @param args The PdfGeneratorArgs object that contains the data to build the result pdf content.
     * @returns A content array that is the content of the result pdf.
     */
    private static buildContent;
    /**
     * Appends the SmartSearch results to the content array of the result pdf.
     * @private
     * @static
     * @param {ApiResponse} apiResponse The ApiResponse containing the SmartSearch results.
     * @param {any[]} content The content array of the result pdf.
     * @memberof PdfGenerator
     */
    private static buildSmartSearchResultsContent;
    /**
     * Fills the content array of the pdf with the result texts from the array of AnalysisGroupResult objects.
     * @param analysisResultsGroups An array of AnalysisResultGroup objects.
     * @param content The content of result pdf that is extended.
     */
    private static buildAnalysisResultGroupArrayContent;
    /**
     * Appends the result text of a single AnalysisResultGroup to the content array of the result pdf.
     * @param analysisResultGroup The AnalysisResultGroup object that contains the result data.
     * @param content The content array of the result pdf that is extended with result texts.
     */
    private static buildAnalysisResultGroupContent;
    /**
     * Fills the content array of the result pdf with the result texts for each criterion from an ApiResponse.
     * @private
     * @static
     * @param {ApiResponse} apiResponse The ApiResponse that contains the analysis results.
     * @param {any[]} content The content array of the result pdf.
     * @memberof PdfGenerator
     */
    private static buildAnalysisResultsArrayContent;
    /**
     * Appends the result texts for a single criterion from an ApiResponse.
     * @private
     * @static
     * @param {ApiResponse} apiResponse The ApiResponse containing the analysis results.
     * @param {AnalysisResults} analysisResults The AnalysisResults object from a single criterion that contains the result texts.
     * @param {any[]} content The content array of the result pdf.
     * @return {void}
     * @memberof PdfGenerator
     */
    private static buildAnalysisResultsContent;
    /**
     * Generates a new result pdf and opens it in a new browser tab.
     * @static
     * @param {ApiResponse} [apiResponse] The ApiResponse that contains the analysis results.
     * @param {AnalysisResultGroup[]} [analysisResultGroups] The array of AnalysisResultGroup objects that contain the analysis results.
     * @param {string} [originalFilename] An optional parameter if the name of the analysed file should appear in the result pdf.
     * @param {string} [pdfTitle] An optional parameter that allows to adapt the title of the result pdf.
     * @memberof PdfGenerator
     */
    static generateAndOpenPdf(apiResponse: ApiResponse, pdfOptions?: PdfGeneratorOptions): void;
    /**
     * Generates a new result pdf and downloads it.
     * @static
     * @param {ApiResponse} [apiResponse] The ApiResponse that contains the analysis results.
     * @param {AnalysisResultGroup[]} [analysisResultGroups] The array of AnalysisResultGroup objects that contain the analysis results.
     * @param {string} [originalFilename] An optional parameter if the name of the analysed file should appear in the result pdf.
     * @param {string} [pdfTitle] An optional parameter that allows to adapt the title of the result pdf.
     * @param {string} [pdfDownloadFilename] The name of the result pdf file that is downloaded.
     * @memberof PdfGenerator
     */
    static generateAndDownloadPdf(apiResponse: ApiResponse, pdfOptions?: PdfGeneratorOptions): void;
    /**
     * Generates a new result pdf and opens a new browser tab to with the pdf opened in print preview.
     * @static
     * @param {ApiResponse} [apiResponse] The ApiResponse that contains the analysis results.
     * @param {AnalysisResultGroup[]} [analysisResultGroups] The array of AnalysisResultGroup objects that contain the analysis results.
     * @param {string} [originalFilename] An optional parameter if the name of the analysed file should appear in the result pdf.
     * @param {string} [pdfTitle] An optional parameter that allows to adapt the title of the result pdf.
     * @memberof PdfGenerator
     */
    static generateAndPrintPdf(apiResponse: ApiResponse, pdfOptions?: PdfGeneratorOptions): void;
    /**
     * Generates a new result pdf and returns a promise that eventually resolves to the URL of the file.
     * @static
     * @param {ApiResponse} [apiResponse] The ApiResponse that contains the analysis results.
     * @param {AnalysisResultGroup[]} [analysisResultGroups] The array of AnalysisResultGroup objects that contain the analysis results.
     * @param {string} [originalFilename] An optional parameter if the name of the analysed file should appear in the result pdf.
     * @param {string} [pdfTitle] An optional parameter that allows to adapt the title of the result pdf.
     * @return {Promise<string>} Returns a new Promise<string> that resolves to the URL of the result pdf.
     * @memberof PdfGenerator
     */
    static generatePdfAndGetDataUrl(apiResponse: ApiResponse, pdfOptions?: PdfGeneratorOptions): Promise<string>;
    /**
     * Generates a new result pdf and returns a promise that eventually resolves to a Base64 encoded string of the result pdf.
     * @static
     * @param {ApiResponse} [apiResponse] The ApiResponse that contains the analysis results.
     * @param {AnalysisResultGroup[]} [analysisResultGroups] The array of AnalysisResultGroup objects that contain the analysis results.
     * @param {string} [originalFilename] An optional parameter if the name of the analysed file should appear in the result pdf.
     * @param {string} [pdfTitle] An optional parameter that allows to adapt the title of the result pdf.
     * @return {Promise<string>} Returns a new Promise<string> that resolves to the Base64-encoded string of the result pdf.
     * @memberof PdfGenerator
     */
    static generatePdfAndGetBase64(apiResponse: ApiResponse, pdfOptions?: PdfGeneratorOptions): Promise<string>;
    /**
     * Generates a new result pdf and returns a promise that eventually resolves to the Blob of the file.
     * @static
     * @param {ApiResponse} [apiResponse] The ApiResponse that contains the analysis results.
     * @param {AnalysisResultGroup[]} [analysisResultGroups] The array of AnalysisResultGroup objects that contain the analysis results.
     * @param {string} [originalFilename] An optional parameter if the name of the analysed file should appear in the result pdf.
     * @param {string} [pdfTitle] An optional parameter that allows to adapt the title of the result pdf.
     * @return {Promis<Blob>} Returns a new Promise<Blob> that eventually resolves to the Blob of the result pdf.
     * @memberof PdfGenerator
     */
    static generatePdfAndGetBlob(apiResponse: ApiResponse, pdfOptions?: PdfGeneratorOptions): Promise<Blob>;
    /**
     * Generates a new result pdf and returns a promise that eventually resolves to a Buffer of the file.
     * @static
     * @param {ApiResponse} apiResponse The ApiResponse that contains the analysis results.
     * @param {AnalysisResultGroup[]} [analysisResultGroups] The array of AnalysisResultGroup objects that contain the analysis results.
     * @param {string} [originalFilename] An optional parameter if the name of the analysed file should appear in the result pdf.
     * @param {string} [pdfTitle] An optional parameter that allows to adapt the title of the result pdf.
     * @return {Promise<Buffer>} Returns a new Promise<Buffer> that resolves to a Buffer of the result pdf.
     * @memberof PdfGenerator
     */
    static generatePdfAndGetBuffer(apiResponse: ApiResponse, pdfOptions?: PdfGeneratorOptions): Promise<Buffer>;
    /**
     * Generates a new result pdf and returns a PdfKit.PDFDocument object.
     * @static
     * @param {ApiResponse} [apiResponse] The ApiResponse that contains the analysis results.
     * @param {AnalysisResultGroup[]} [analysisResultGroups] The array of AnalysisResultGroup objects that contain the analysis results.
     * @param {string} [originalFilename] An optional parameter if the name of the analysed file should appear in the result pdf.
     * @param {string} [pdfTitle] An optional parameter that allows to adapt the title of the result pdf.
     * @return {PDFKit.PDFDocument}
     * @memberof PdfGenerator
     */
    static generatePdfAndGetStream(apiResponse: ApiResponse, pdfOptions?: PdfGeneratorOptions): PDFKit.PDFDocument;
}
/**
 * The possible operations that can be performed on a created TCreatedPdf object with the PDFGenerator.
 * They are
 *  - FILE_OPEN: Opens the result pdf file in a new tab.
 *  - DOWNLOAD: Downloads the result pdf file. Allows to specify the name of the result pdf file.
 *  - PRINT: Opens the result pdf in a new tab in print mode.
 *  - DATA_URL: Creates a new File and returns its local URL.
 *  - BASE64: Returns the result pdf as a Base64-encoded string.
 *  - BLOB: Returns the result pdf as a Blob.
 *  - BUFFER: Returns the result pdf as a Buffer.
 *  - PDFKIT_DOCUMENT: Returns the result pdf as a PdfKit.PdfDocument object.
 * @export
 * @enum {number}
 */
export declare enum PdfGeneratorResultType {
    FILE_OPEN = 0,
    DOWNLOAD = 1,
    PRINT = 2,
    DATA_URL = 3,
    BASE64 = 4,
    BLOB = 5,
    BUFFER = 6,
    PDFKIT_DOCUMENT = 7
}
/**
 * Data for the PDFGenerator to create a PDF file.
 * title: The title of the to-be-created pdf file.
 * originalFilename: The name of the document that was analysed.
 * analysisResultGroups: A list of AnalysisResultGroup objects that contains the analysis results.
 * pdfDownloadFilename: Determines the name of the downloaded file if the resultType DOWNLOAD is chosen.
 */
export declare type PdfGeneratorOptions = {
    language?: Language;
    pdfTitle?: string;
    originalFilename?: string;
    analysisResultGroups?: AnalysisResultGroup[];
    pdfDownloadFilename?: string;
};
