/// <reference types="node" />
/// <reference types="pdfkit" />
import { PdfGeneratorOptions, PdfGeneratorResultType } from '../helpers/PdfGenerator';
import { AnalysisResults } from './AnalysisResults';
import { ApiCriterionMetadataKey } from './ApiCriterionMetadataKey';
import { ApiDocumentMetadataKey } from './ApiDocumentMetadataKey';
import { ApiError } from './ApiError';
import { ApiMetadata } from './ApiMetadata';
import { Clause } from './Clause';
import { Criterion } from './Criterion';
import { GeometricData } from './GeometricData';
import { MetaDataEntity } from './MetaDataEntity';
import { SmartSearchMetadataKey } from './SmartSearchMetadataKey';
import { SmartSearchResult } from './SmartSearchResult';
/**
 * <ul>
 *   <li>documentText - The analyzed text in the (during the request) uploaded file.</li>
 *   <li>results      - Object from the UUID of a criterion to the analysis result. Defaults to an empty Object.</li>
 *   <li>errors       - {@link Array} of errors which occurred during the process. This parameter defaults to an empty {@link Array}.</li>
 * </ul>
 *
 */
export declare type ApiResponseObject = {
    documentText: string;
    results: {
        [p: string]: AnalysisResults;
    };
    smartSearchResults: {
        [p: string]: Array<SmartSearchResult>;
    };
    errors: readonly ApiError[];
    documentMetadata: {
        [p: string]: ApiMetadata<MetaDataEntity>;
    };
    promiseId: string;
    geometricData: GeometricData;
};
/**
 * Response of the Juracus API to an {@link ApiRequest}.
 *
 * @author Onur Gürsoy
 */
export declare class ApiResponse {
    readonly documentText: string;
    readonly results: {
        [p: string]: AnalysisResults;
    };
    readonly smartSearchResults: {
        [p: string]: Array<SmartSearchResult>;
    };
    readonly errors: readonly ApiError[];
    readonly documentMetadata: {
        [p: number]: ApiMetadata<MetaDataEntity>;
    };
    readonly promiseId: string;
    private readonly geometricData;
    /**
     * Constructs a new {@link ApiResponse} object as answer to an {@link ApiRequest}.
     *
     * @param responseParameters containing data to construct ApiResponse
     */
    constructor(responseParameters: ApiResponseObject);
    /**
     * Returns the analysis results for the specified criterion.
     *
     * @param criterion - {@link Criterion} to get the analysis results for.
     * @return {@link AnalysisResults} object containing the results.
     */
    readonly getResult: (criterion: Criterion) => AnalysisResults;
    /**
     * Returns the SmartSearchResults for the specified task.
     *
     * @param taskId - {@link taskId} to get the analysis results for.
     * @return {@link SmartSearchResult} object containing the results.
     */
    readonly getSmartSearchResult: (taskId: string) => SmartSearchResult[];
    readonly getGeometricData: () => GeometricData;
    readonly hasGeometricData: () => boolean;
    /**
     * Returns the texts found by the Juracus AI which are classified as relevant to the given criterion.
     *
     * @param criterion - {@link Criterion} to get the as relevant classified text passages for.
     * @return {@link List} of all as relevant for the given criterion specified text passages.
     * <p>
     * <strong>IMPORTANT</strong>
     * The returned list can still be empty if the Juracus AI did not find any relevant texts for the specified criterion.
     * </p>
     * @throws Error if the Juracus AI was not able to analyze the specified criterion.
     *                                <p>
     *                                <strong>IMPORTANT</strong>
     *                                the returned list may still be empty if no exception is thrown if the Juracus AI did not find any relevant text for the criterion but tried to analyze it.
     *                                </p>
     */
    readonly getClauses: (criterion: Criterion) => Clause[];
    /**
     * Returns metadata which is not directly connected to analyzed criteria but to the whole document based on the provided {@link ApiDocumentMetadataKey}.
     * @param key which identifies what kind of data is requested.
     * @return {@link ApiMetadata} object.
     */
    readonly getDocumentMetadata: (key: ApiDocumentMetadataKey, asMetadataEntity?: boolean) => any[];
    readonly getCriterionMetadata: (criterion: Criterion, key: ApiCriterionMetadataKey, asMetadataEntity?: boolean) => any[];
    readonly getSmartSearchMetadata: (smartSearchTaskId: string, key: SmartSearchMetadataKey, asMetadataEntity?: boolean) => any[];
    /**
     * Checks whether or not errors occurred during the API call.
     * @return {@code true} if errors occurred and {@code false} otherwise.
     */
    readonly hasErrors: () => boolean;
    /**
     * Allows to create pdf documents from the analysis results and offers various methods to retrieve them.
     * For a list of all possible modes of retrieval, see (@type {PdfGeneratorResultType}).
     * Either the apiResponse or the analysisGroupsResults can be used for the creation, one of them must be null.
     * @static
     * @param {ApiResponse} apiResponse The ApiResponse containing the analysis results. Using this will create a paragraph for the results of every criterion that was analysed.
     * @param {AnalysisResultGroup[]} [analysisResultGroups] The array of AnalysisResultGroup object containing the analysis results. Using this allows to group results from multiple criteria under one name. For AnalysisResultGroup a new paragraph is created.
     * @param {PdfGeneratorResultType} [resultType] The mode of retrieval. For a description of all possible modes, see (@type {PdfGeneratorResultType}).
     * @param {string} [originalFilename] An optional parameter if the name of the analysed file should appear in the result pdf.
     * @param {string} [pdfDownloadFilename] An optional parameter that can be used if (and only if) the mode "DOWNLOAD" is chosen to determine the name the downloaded file. For all other modes, this parameter has no effect.
     * @param {string} [pdfTitle] The title of the result pdf.
     * @memberof ApiResponse
     */
    static readonly getAnalysisPdf: (apiResponse: ApiResponse, resultType: PdfGeneratorResultType, pdfOptions?: PdfGeneratorOptions) => void | Promise<string> | Promise<Buffer> | PDFKit.PDFDocument | Promise<Blob>;
}
